# pyHusteblume

## Installation
Install the dependencies using pip:
`pip install -r requirements.txt`

## Usage
`python3 main.py`

## Example

```
{'user-agent': 'okhttp/4.4.0'}
<husteblume.api.Stations object at 0x105b713d0>
'DEHANN'
<User: appId=6C17808F>
{'authorization': 'Basic NkMxNzgwOEY6bmxZTGtkVnNpWm5SR2tzTWpwa01aeFFoY2o=',
 'user-agent': 'okhttp/4.4.0'}
<husteblume.api.Forecast object at 0x104d84eb0>
{'ALNU': [0, 0, 0],
 'AMBR': [0, 0, 0],
 'ARTE': [1, 1, 1],
 'BETU': [0, 0, 0],
 'CORY': [0, 0, 0],
 'FRAX': [0, 0, 0],
 'POAC': [2, 2, 2],
 'SECA': [0, 0, 0]}
```
